[Pkg-privacy-commits] [libotr] 111/225: Add otrl_ to the names of two exported context_priv functions

Ximin Luo infinity0 at moszumanska.debian.org
Sat Aug 22 12:45:06 UTC 2015


This is an automated email from the git hooks/post-receive script.

infinity0 pushed a commit to branch master
in repository libotr.

commit 0e10a590da60bd4ea120d4fa1c935e37fe7c0014
Author: Ian Goldberg <iang at cs.uwaterloo.ca>
Date:   Sun Aug 26 13:38:34 2012 -0400

    Add otrl_ to the names of two exported context_priv functions
    
    libotr was exporting exactly two functions without the otrl_ prefix:
    context_priv_new and context_priv_force_finished.  Change the names of
    these functions to start with otrl_.  Thanks to David Goulet
    <dgoulet at ev0ke.net> for noticing it.
---
 ChangeLog          | 10 ++++++++++
 src/context.c      |  4 ++--
 src/context_priv.c |  4 ++--
 src/context_priv.h |  6 +++---
 4 files changed, 17 insertions(+), 7 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 0ae34dd..f0e4107 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,13 @@
+2012-08-26
+
+	* src/context.c:
+	* src/context_priv.c:
+	* src/context_priv.h: libotr was exporting exactly two functions
+	without the otrl_ prefix: context_priv_new and
+	context_priv_force_finished.  Change the names of these
+	functions to start with otrl_.  Thanks to David Goulet
+	<dgoulet at ev0ke.net> for noticing it.
+
 2012-08-25
 
 	* src/sm.c:
diff --git a/src/context.c b/src/context.c
index 6b415a6..bdde699 100644
--- a/src/context.c
+++ b/src/context.c
@@ -154,7 +154,7 @@ static ConnContext * new_context(const char * user, const char * accountname,
     context->otr_offer = OFFER_NOT;
     context->app_data = NULL;
     context->app_data_free = NULL;
-    context->context_priv = context_priv_new();
+    context->context_priv = otrl_context_priv_new();
     assert(context->context_priv != NULL);
     context->next = NULL;
     context->m_context = context;
@@ -420,7 +420,7 @@ void otrl_context_force_finished(ConnContext *context)
     context->sessionid_len = 0;
     context->protocol_version = 0;
     otrl_sm_state_free(context->smstate);
-    context_priv_force_finished(context->context_priv);
+    otrl_context_priv_force_finished(context->context_priv);
 }
 
 /* Force a context into the OTRL_MSGSTATE_PLAINTEXT state. */
diff --git a/src/context_priv.c b/src/context_priv.c
index 7c568c7..47d05b9 100644
--- a/src/context_priv.c
+++ b/src/context_priv.c
@@ -29,7 +29,7 @@
 #include "context_priv.h"
 
 /* Create a new private connection context */
-ConnContextPriv *context_priv_new()
+ConnContextPriv *otrl_context_priv_new()
 {
 	ConnContextPriv *context_priv;
 	context_priv = malloc(sizeof(*context_priv));
@@ -67,7 +67,7 @@ ConnContextPriv *context_priv_new()
 /* Resets the appropriate variables when a context
  * is being force finished
  */
-void context_priv_force_finished(ConnContextPriv *context_priv)
+void otrl_context_priv_force_finished(ConnContextPriv *context_priv)
 {
 	free(context_priv->fragment);
 	context_priv->fragment = NULL;
diff --git a/src/context_priv.h b/src/context_priv.h
index c17b11a..0748074 100644
--- a/src/context_priv.h
+++ b/src/context_priv.h
@@ -86,9 +86,9 @@ typedef struct context_priv {
 } ConnContextPriv;
 
 /* Create a new private connection context. */
-ConnContextPriv *context_priv_new();
+ConnContextPriv *otrl_context_priv_new();
 
-/* Frees up memory that was used in context_priv_new */
-void context_priv_force_finished(ConnContextPriv *context_priv);
+/* Frees up memory that was used in otrl_context_priv_new */
+void otrl_context_priv_force_finished(ConnContextPriv *context_priv);
 
 #endif

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-privacy/packages/libotr.git



More information about the Pkg-privacy-commits mailing list